package com.bitlove.fetlife.util;

import android.text.TextUtils;

import java.io.UnsupportedEncodingException;
import java.util.HashMap;
import java.util.Map;

public class EmojiUtil {

    private static final HashMap<Integer, String> emojisMap;
    public static final String[] emojiUnicodes;
    public static final String[] emojiEscapes;
    private static final String[] emojiRemoval;

    public static String removeEmojis(String text) {
        return TextUtils.replace(text, emojiUnicodes, emojiRemoval).toString();
    }

    public static String escapeEmojis(String text) {
        return TextUtils.replace(text, emojiUnicodes, emojiEscapes).toString();
    }

    public static String deEscapeEmojis(String text) {
        return TextUtils.replace(text, emojiEscapes, emojiUnicodes).toString();
    }

    static {
        emojisMap = new HashMap<>();
        initEmojiMap();
        emojiUnicodes = new String[emojisMap.size()];
        emojiEscapes = new String[emojisMap.size()];
        emojiRemoval = new String[emojisMap.size()];
        try {
            convertEmojiMapToArrays();
        } catch (UnsupportedEncodingException e) {
        }
    }

    private static void convertEmojiMapToArrays() throws UnsupportedEncodingException {
        int index = 0;
        for (Map.Entry<Integer, String> mapEntry : emojisMap.entrySet()) {
            emojiUnicodes[index] = new String(Character.toChars(mapEntry.getKey()));
            emojiEscapes[index] = mapEntry.getValue();
            emojiRemoval[index] = "";
            index++;
        }
    }

    static void initEmojiMap() {

        // People
        emojisMap.put(0x1f604, ":emoji_1f604:");
        emojisMap.put(0x1f603, ":emoji_1f603:");
        emojisMap.put(0x1f600, ":emoji_1f600:");
        emojisMap.put(0x1f60a, ":emoji_1f60a:");
        emojisMap.put(0x263a, ":emoji_263a:");
        emojisMap.put(0x1f609, ":emoji_1f609:");
        emojisMap.put(0x1f60d, ":emoji_1f60d:");
        emojisMap.put(0x1f618, ":emoji_1f618:");
        emojisMap.put(0x1f61a, ":emoji_1f61a:");
        emojisMap.put(0x1f617, ":emoji_1f617:");
        emojisMap.put(0x1f619, ":emoji_1f619:");
        emojisMap.put(0x1f61c, ":emoji_1f61c:");
        emojisMap.put(0x1f61d, ":emoji_1f61d:");
        emojisMap.put(0x1f61b, ":emoji_1f61b:");
        emojisMap.put(0x1f633, ":emoji_1f633:");
        emojisMap.put(0x1f601, ":emoji_1f601:");
        emojisMap.put(0x1f614, ":emoji_1f614:");
        emojisMap.put(0x1f60c, ":emoji_1f60c:");
        emojisMap.put(0x1f612, ":emoji_1f612:");
        emojisMap.put(0x1f61e, ":emoji_1f61e:");
        emojisMap.put(0x1f623, ":emoji_1f623:");
        emojisMap.put(0x1f622, ":emoji_1f622:");
        emojisMap.put(0x1f602, ":emoji_1f602:");
        emojisMap.put(0x1f62d, ":emoji_1f62d:");
        emojisMap.put(0x1f62a, ":emoji_1f62a:");
        emojisMap.put(0x1f625, ":emoji_1f625:");
        emojisMap.put(0x1f630, ":emoji_1f630:");
        emojisMap.put(0x1f605, ":emoji_1f605:");
        emojisMap.put(0x1f613, ":emoji_1f613:");
        emojisMap.put(0x1f629, ":emoji_1f629:");
        emojisMap.put(0x1f62b, ":emoji_1f62b:");
        emojisMap.put(0x1f628, ":emoji_1f628:");
        emojisMap.put(0x1f631, ":emoji_1f631:");
        emojisMap.put(0x1f620, ":emoji_1f620:");
        emojisMap.put(0x1f621, ":emoji_1f621:");
        emojisMap.put(0x1f624, ":emoji_1f624:");
        emojisMap.put(0x1f616, ":emoji_1f616:");
        emojisMap.put(0x1f606, ":emoji_1f606:");
        emojisMap.put(0x1f60b, ":emoji_1f60b:");
        emojisMap.put(0x1f637, ":emoji_1f637:");
        emojisMap.put(0x1f60e, ":emoji_1f60e:");
        emojisMap.put(0x1f634, ":emoji_1f634:");
        emojisMap.put(0x1f635, ":emoji_1f635:");
        emojisMap.put(0x1f632, ":emoji_1f632:");
        emojisMap.put(0x1f61f, ":emoji_1f61f:");
        emojisMap.put(0x1f626, ":emoji_1f626:");
        emojisMap.put(0x1f627, ":emoji_1f627:");
        emojisMap.put(0x1f608, ":emoji_1f608:");
        emojisMap.put(0x1f47f, ":emoji_1f47f:");
        emojisMap.put(0x1f62e, ":emoji_1f62e:");
        emojisMap.put(0x1f62c, ":emoji_1f62c:");
        emojisMap.put(0x1f610, ":emoji_1f610:");
        emojisMap.put(0x1f615, ":emoji_1f615:");
        emojisMap.put(0x1f62f, ":emoji_1f62f:");
        emojisMap.put(0x1f636, ":emoji_1f636:");
        emojisMap.put(0x1f607, ":emoji_1f607:");
        emojisMap.put(0x1f60f, ":emoji_1f60f:");
        emojisMap.put(0x1f611, ":emoji_1f611:");
        emojisMap.put(0x1f472, ":emoji_1f472:");
        emojisMap.put(0x1f473, ":emoji_1f473:");
        emojisMap.put(0x1f46e, ":emoji_1f46e:");
        emojisMap.put(0x1f477, ":emoji_1f477:");
        emojisMap.put(0x1f482, ":emoji_1f482:");
        emojisMap.put(0x1f476, ":emoji_1f476:");
        emojisMap.put(0x1f466, ":emoji_1f466:");
        emojisMap.put(0x1f467, ":emoji_1f467:");
        emojisMap.put(0x1f468, ":emoji_1f468:");
        emojisMap.put(0x1f469, ":emoji_1f469:");
        emojisMap.put(0x1f474, ":emoji_1f474:");
        emojisMap.put(0x1f475, ":emoji_1f475:");
        emojisMap.put(0x1f471, ":emoji_1f471:");
        emojisMap.put(0x1f47c, ":emoji_1f47c:");
        emojisMap.put(0x1f478, ":emoji_1f478:");
        emojisMap.put(0x1f63a, ":emoji_1f63a:");
        emojisMap.put(0x1f638, ":emoji_1f638:");
        emojisMap.put(0x1f63b, ":emoji_1f63b:");
        emojisMap.put(0x1f63d, ":emoji_1f63d:");
        emojisMap.put(0x1f63c, ":emoji_1f63c:");
        emojisMap.put(0x1f640, ":emoji_1f640:");
        emojisMap.put(0x1f63f, ":emoji_1f63f:");
        emojisMap.put(0x1f639, ":emoji_1f639:");
        emojisMap.put(0x1f63e, ":emoji_1f63e:");
        emojisMap.put(0x1f479, ":emoji_1f479:");
        emojisMap.put(0x1f47a, ":emoji_1f47a:");
        emojisMap.put(0x1f648, ":emoji_1f648:");
        emojisMap.put(0x1f649, ":emoji_1f649:");
        emojisMap.put(0x1f64a, ":emoji_1f64a:");
        emojisMap.put(0x1f480, ":emoji_1f480:");
        emojisMap.put(0x1f47d, ":emoji_1f47d:");
        emojisMap.put(0x1f4a9, ":emoji_1f4a9:");
        emojisMap.put(0x1f525, ":emoji_1f525:");
        emojisMap.put(0x2728, ":emoji_2728:");
        emojisMap.put(0x1f31f, ":emoji_1f31f:");
        emojisMap.put(0x1f4ab, ":emoji_1f4ab:");
        emojisMap.put(0x1f4a5, ":emoji_1f4a5:");
        emojisMap.put(0x1f4a2, ":emoji_1f4a2:");
        emojisMap.put(0x1f4a6, ":emoji_1f4a6:");
        emojisMap.put(0x1f4a7, ":emoji_1f4a7:");
        emojisMap.put(0x1f4a4, ":emoji_1f4a4:");
        emojisMap.put(0x1f4a8, ":emoji_1f4a8:");
        emojisMap.put(0x1f442, ":emoji_1f442:");
        emojisMap.put(0x1f440, ":emoji_1f440:");
        emojisMap.put(0x1f443, ":emoji_1f443:");
        emojisMap.put(0x1f445, ":emoji_1f445:");
        emojisMap.put(0x1f444, ":emoji_1f444:");
        emojisMap.put(0x1f44d, ":emoji_1f44d:");
        emojisMap.put(0x1f44e, ":emoji_1f44e:");
        emojisMap.put(0x1f44c, ":emoji_1f44c:");
        emojisMap.put(0x1f44a, ":emoji_1f44a:");
        emojisMap.put(0x270a, ":emoji_270a:");
        emojisMap.put(0x270c, ":emoji_270c:");
        emojisMap.put(0x1f44b, ":emoji_1f44b:");
        emojisMap.put(0x270b, ":emoji_270b:");
        emojisMap.put(0x1f450, ":emoji_1f450:");
        emojisMap.put(0x1f446, ":emoji_1f446:");
        emojisMap.put(0x1f447, ":emoji_1f447:");
        emojisMap.put(0x1f449, ":emoji_1f449:");
        emojisMap.put(0x1f448, ":emoji_1f448:");
        emojisMap.put(0x1f64c, ":emoji_1f64c:");
        emojisMap.put(0x1f64f, ":emoji_1f64f:");
        emojisMap.put(0x261d, ":emoji_261d:");
        emojisMap.put(0x1f44f, ":emoji_1f44f:");
        emojisMap.put(0x1f4aa, ":emoji_1f4aa:");
        emojisMap.put(0x1f6b6, ":emoji_1f6b6:");
        emojisMap.put(0x1f3c3, ":emoji_1f3c3:");
        emojisMap.put(0x1f483, ":emoji_1f483:");
        emojisMap.put(0x1f46b, ":emoji_1f46b:");
        emojisMap.put(0x1f46a, ":emoji_1f46a:");
        emojisMap.put(0x1f46c, ":emoji_1f46c:");
        emojisMap.put(0x1f46d, ":emoji_1f46d:");
        emojisMap.put(0x1f48f, ":emoji_1f48f:");
        emojisMap.put(0x1f491, ":emoji_1f491:");
        emojisMap.put(0x1f46f, ":emoji_1f46f:");
        emojisMap.put(0x1f646, ":emoji_1f646:");
        emojisMap.put(0x1f645, ":emoji_1f645:");
        emojisMap.put(0x1f481, ":emoji_1f481:");
        emojisMap.put(0x1f64b, ":emoji_1f64b:");
        emojisMap.put(0x1f486, ":emoji_1f486:");
        emojisMap.put(0x1f487, ":emoji_1f487:");
        emojisMap.put(0x1f485, ":emoji_1f485:");
        emojisMap.put(0x1f470, ":emoji_1f470:");
        emojisMap.put(0x1f64e, ":emoji_1f64e:");
        emojisMap.put(0x1f64d, ":emoji_1f64d:");
        emojisMap.put(0x1f647, ":emoji_1f647:");
        emojisMap.put(0x1f3a9, ":emoji_1f3a9:");
        emojisMap.put(0x1f451, ":emoji_1f451:");
        emojisMap.put(0x1f452, ":emoji_1f452:");
        emojisMap.put(0x1f45f, ":emoji_1f45f:");
        emojisMap.put(0x1f45e, ":emoji_1f45e:");
        emojisMap.put(0x1f461, ":emoji_1f461:");
        emojisMap.put(0x1f460, ":emoji_1f460:");
        emojisMap.put(0x1f462, ":emoji_1f462:");
        emojisMap.put(0x1f455, ":emoji_1f455:");
        emojisMap.put(0x1f454, ":emoji_1f454:");
        emojisMap.put(0x1f45a, ":emoji_1f45a:");
        emojisMap.put(0x1f457, ":emoji_1f457:");
        emojisMap.put(0x1f3bd, ":emoji_1f3bd:");
        emojisMap.put(0x1f456, ":emoji_1f456:");
        emojisMap.put(0x1f458, ":emoji_1f458:");
        emojisMap.put(0x1f459, ":emoji_1f459:");
        emojisMap.put(0x1f4bc, ":emoji_1f4bc:");
        emojisMap.put(0x1f45c, ":emoji_1f45c:");
        emojisMap.put(0x1f45d, ":emoji_1f45d:");
        emojisMap.put(0x1f45b, ":emoji_1f45b:");
        emojisMap.put(0x1f453, ":emoji_1f453:");
        emojisMap.put(0x1f380, ":emoji_1f380:");
        emojisMap.put(0x1f302, ":emoji_1f302:");
        emojisMap.put(0x1f484, ":emoji_1f484:");
        emojisMap.put(0x1f49b, ":emoji_1f49b:");
        emojisMap.put(0x1f499, ":emoji_1f499:");
        emojisMap.put(0x1f49c, ":emoji_1f49c:");
        emojisMap.put(0x1f49a, ":emoji_1f49a:");
        emojisMap.put(0x2764, ":emoji_2764:");
        emojisMap.put(0x1f494, ":emoji_1f494:");
        emojisMap.put(0x1f497, ":emoji_1f497:");
        emojisMap.put(0x1f493, ":emoji_1f493:");
        emojisMap.put(0x1f495, ":emoji_1f495:");
        emojisMap.put(0x1f496, ":emoji_1f496:");
        emojisMap.put(0x1f49e, ":emoji_1f49e:");
        emojisMap.put(0x1f498, ":emoji_1f498:");
        emojisMap.put(0x1f48c, ":emoji_1f48c:");
        emojisMap.put(0x1f48b, ":emoji_1f48b:");
        emojisMap.put(0x1f48d, ":emoji_1f48d:");
        emojisMap.put(0x1f48e, ":emoji_1f48e:");
        emojisMap.put(0x1f464, ":emoji_1f464:");
        emojisMap.put(0x1f465, ":emoji_1f465:");
        emojisMap.put(0x1f4ac, ":emoji_1f4ac:");
        emojisMap.put(0x1f463, ":emoji_1f463:");
        emojisMap.put(0x1f4ad, ":emoji_1f4ad:");

        // Nature
        emojisMap.put(0x1f436, ":emoji_1f436:");
        emojisMap.put(0x1f43a, ":emoji_1f43a:");
        emojisMap.put(0x1f431, ":emoji_1f431:");
        emojisMap.put(0x1f42d, ":emoji_1f42d:");
        emojisMap.put(0x1f439, ":emoji_1f439:");
        emojisMap.put(0x1f430, ":emoji_1f430:");
        emojisMap.put(0x1f438, ":emoji_1f438:");
        emojisMap.put(0x1f42f, ":emoji_1f42f:");
        emojisMap.put(0x1f428, ":emoji_1f428:");
        emojisMap.put(0x1f43b, ":emoji_1f43b:");
        emojisMap.put(0x1f437, ":emoji_1f437:");
        emojisMap.put(0x1f43d, ":emoji_1f43d:");
        emojisMap.put(0x1f42e, ":emoji_1f42e:");
        emojisMap.put(0x1f417, ":emoji_1f417:");
        emojisMap.put(0x1f435, ":emoji_1f435:");
        emojisMap.put(0x1f412, ":emoji_1f412:");
        emojisMap.put(0x1f434, ":emoji_1f434:");
        emojisMap.put(0x1f411, ":emoji_1f411:");
        emojisMap.put(0x1f418, ":emoji_1f418:");
        emojisMap.put(0x1f43c, ":emoji_1f43c:");
        emojisMap.put(0x1f427, ":emoji_1f427:");
        emojisMap.put(0x1f426, ":emoji_1f426:");
        emojisMap.put(0x1f424, ":emoji_1f424:");
        emojisMap.put(0x1f425, ":emoji_1f425:");
        emojisMap.put(0x1f423, ":emoji_1f423:");
        emojisMap.put(0x1f414, ":emoji_1f414:");
        emojisMap.put(0x1f40d, ":emoji_1f40d:");
        emojisMap.put(0x1f422, ":emoji_1f422:");
        emojisMap.put(0x1f41b, ":emoji_1f41b:");
        emojisMap.put(0x1f41d, ":emoji_1f41d:");
        emojisMap.put(0x1f41c, ":emoji_1f41c:");
        emojisMap.put(0x1f41e, ":emoji_1f41e:");
        emojisMap.put(0x1f40c, ":emoji_1f40c:");
        emojisMap.put(0x1f419, ":emoji_1f419:");
        emojisMap.put(0x1f41a, ":emoji_1f41a:");
        emojisMap.put(0x1f420, ":emoji_1f420:");
        emojisMap.put(0x1f41f, ":emoji_1f41f:");
        emojisMap.put(0x1f42c, ":emoji_1f42c:");
        emojisMap.put(0x1f433, ":emoji_1f433:");
        emojisMap.put(0x1f40b, ":emoji_1f40b:");
        emojisMap.put(0x1f404, ":emoji_1f404:");
        emojisMap.put(0x1f40f, ":emoji_1f40f:");
        emojisMap.put(0x1f400, ":emoji_1f400:");
        emojisMap.put(0x1f403, ":emoji_1f403:");
        emojisMap.put(0x1f405, ":emoji_1f405:");
        emojisMap.put(0x1f407, ":emoji_1f407:");
        emojisMap.put(0x1f409, ":emoji_1f409:");
        emojisMap.put(0x1f40e, ":emoji_1f40e:");
        emojisMap.put(0x1f410, ":emoji_1f410:");
        emojisMap.put(0x1f413, ":emoji_1f413:");
        emojisMap.put(0x1f415, ":emoji_1f415:");
        emojisMap.put(0x1f416, ":emoji_1f416:");
        emojisMap.put(0x1f401, ":emoji_1f401:");
        emojisMap.put(0x1f402, ":emoji_1f402:");
        emojisMap.put(0x1f432, ":emoji_1f432:");
        emojisMap.put(0x1f421, ":emoji_1f421:");
        emojisMap.put(0x1f40a, ":emoji_1f40a:");
        emojisMap.put(0x1f42b, ":emoji_1f42b:");
        emojisMap.put(0x1f42a, ":emoji_1f42a:");
        emojisMap.put(0x1f406, ":emoji_1f406:");
        emojisMap.put(0x1f408, ":emoji_1f408:");
        emojisMap.put(0x1f429, ":emoji_1f429:");
        emojisMap.put(0x1f43e, ":emoji_1f43e:");
        emojisMap.put(0x1f490, ":emoji_1f490:");
        emojisMap.put(0x1f338, ":emoji_1f338:");
        emojisMap.put(0x1f337, ":emoji_1f337:");
        emojisMap.put(0x1f340, ":emoji_1f340:");
        emojisMap.put(0x1f339, ":emoji_1f339:");
        emojisMap.put(0x1f33b, ":emoji_1f33b:");
        emojisMap.put(0x1f33a, ":emoji_1f33a:");
        emojisMap.put(0x1f341, ":emoji_1f341:");
        emojisMap.put(0x1f343, ":emoji_1f343:");
        emojisMap.put(0x1f342, ":emoji_1f342:");
        emojisMap.put(0x1f33f, ":emoji_1f33f:");
        emojisMap.put(0x1f33e, ":emoji_1f33e:");
        emojisMap.put(0x1f344, ":emoji_1f344:");
        emojisMap.put(0x1f335, ":emoji_1f335:");
        emojisMap.put(0x1f334, ":emoji_1f334:");
        emojisMap.put(0x1f332, ":emoji_1f332:");
        emojisMap.put(0x1f333, ":emoji_1f333:");
        emojisMap.put(0x1f330, ":emoji_1f330:");
        emojisMap.put(0x1f331, ":emoji_1f331:");
        emojisMap.put(0x1f33c, ":emoji_1f33c:");
        emojisMap.put(0x1f310, ":emoji_1f310:");
        emojisMap.put(0x1f31e, ":emoji_1f31e:");
        emojisMap.put(0x1f31d, ":emoji_1f31d:");
        emojisMap.put(0x1f31a, ":emoji_1f31a:");
        emojisMap.put(0x1f311, ":emoji_1f311:");
        emojisMap.put(0x1f312, ":emoji_1f312:");
        emojisMap.put(0x1f313, ":emoji_1f313:");
        emojisMap.put(0x1f314, ":emoji_1f314:");
        emojisMap.put(0x1f315, ":emoji_1f315:");
        emojisMap.put(0x1f316, ":emoji_1f316:");
        emojisMap.put(0x1f317, ":emoji_1f317:");
        emojisMap.put(0x1f318, ":emoji_1f318:");
        emojisMap.put(0x1f31c, ":emoji_1f31c:");
        emojisMap.put(0x1f31b, ":emoji_1f31b:");
        emojisMap.put(0x1f319, ":emoji_1f319:");
        emojisMap.put(0x1f30d, ":emoji_1f30d:");
        emojisMap.put(0x1f30e, ":emoji_1f30e:");
        emojisMap.put(0x1f30f, ":emoji_1f30f:");
        emojisMap.put(0x1f30b, ":emoji_1f30b:");
        emojisMap.put(0x1f30c, ":emoji_1f30c:");
        emojisMap.put(0x1f320, ":emoji_1f303:");
        emojisMap.put(0x2b50, ":emoji_2b50:");
        emojisMap.put(0x2600, ":emoji_2600:");
        emojisMap.put(0x26c5, ":emoji_26c5:");
        emojisMap.put(0x2601, ":emoji_2601:");
        emojisMap.put(0x26a1, ":emoji_26a1:");
        emojisMap.put(0x2614, ":emoji_2614:");
        emojisMap.put(0x2744, ":emoji_2744:");
        emojisMap.put(0x26c4, ":emoji_26c4:");
        emojisMap.put(0x1f300, ":emoji_1f300:");
        emojisMap.put(0x1f301, ":emoji_1f301:");
        emojisMap.put(0x1f308, ":emoji_1f308:");
        emojisMap.put(0x1f30a, ":emoji_1f30a:");

        // Objects
        emojisMap.put(0x1f38d, ":emoji_1f38d:");
        emojisMap.put(0x1f49d, ":emoji_1f49d:");
        emojisMap.put(0x1f38e, ":emoji_1f38e:");
        emojisMap.put(0x1f392, ":emoji_1f392:");
        emojisMap.put(0x1f393, ":emoji_1f393:");
        emojisMap.put(0x1f38f, ":emoji_1f38f:");
        emojisMap.put(0x1f386, ":emoji_1f386:");
        emojisMap.put(0x1f387, ":emoji_1f387:");
        emojisMap.put(0x1f390, ":emoji_1f390:");
        emojisMap.put(0x1f391, ":emoji_1f391:");
        emojisMap.put(0x1f383, ":emoji_1f383:");
        emojisMap.put(0x1f47b, ":emoji_1f47b:");
        emojisMap.put(0x1f385, ":emoji_1f385:");
        emojisMap.put(0x1f384, ":emoji_1f384:");
        emojisMap.put(0x1f381, ":emoji_1f381:");
        emojisMap.put(0x1f38b, ":emoji_1f38b:");
        emojisMap.put(0x1f389, ":emoji_1f389:");
        emojisMap.put(0x1f38a, ":emoji_1f38a:");
        emojisMap.put(0x1f388, ":emoji_1f388:");
        emojisMap.put(0x1f38c, ":emoji_1f38c:");
        emojisMap.put(0x1f52e, ":emoji_1f52e:");
        emojisMap.put(0x1f3a5, ":emoji_1f3a5:");
        emojisMap.put(0x1f4f7, ":emoji_1f4f7:");
        emojisMap.put(0x1f4f9, ":emoji_1f4f9:");
        emojisMap.put(0x1f4fc, ":emoji_1f4fc:");
        emojisMap.put(0x1f4bf, ":emoji_1f4bf:");
        emojisMap.put(0x1f4c0, ":emoji_1f4c0:");
        emojisMap.put(0x1f4bd, ":emoji_1f4bd:");
        emojisMap.put(0x1f4be, ":emoji_1f4be:");
        emojisMap.put(0x1f4bb, ":emoji_1f4bb:");
        emojisMap.put(0x1f4f1, ":emoji_1f4f1:");
        emojisMap.put(0x260e, ":emoji_260e:");
        emojisMap.put(0x1f4de, ":emoji_1f4de:");
        emojisMap.put(0x1f4df, ":emoji_1f4df:");
        emojisMap.put(0x1f4e0, ":emoji_1f4e0:");
        emojisMap.put(0x1f4e1, ":emoji_1f4e1:");
        emojisMap.put(0x1f4fa, ":emoji_1f4fa:");
        emojisMap.put(0x1f4fb, ":emoji_1f4fb:");
        emojisMap.put(0x1f50a, ":emoji_1f50a:");
        emojisMap.put(0x1f509, ":emoji_1f509:");
        emojisMap.put(0x1f508, ":emoji_1f508:");
        emojisMap.put(0x1f507, ":emoji_1f507:");
        emojisMap.put(0x1f514, ":emoji_1f514:");
        emojisMap.put(0x1f515, ":emoji_1f515:");
        emojisMap.put(0x1f4e2, ":emoji_1f4e2:");
        emojisMap.put(0x1f4e3, ":emoji_1f4e3:");
        emojisMap.put(0x23f3, ":emoji_23f3:");
        emojisMap.put(0x231b, ":emoji_231b:");
        emojisMap.put(0x23f0, ":emoji_23f0:");
        emojisMap.put(0x231a, ":emoji_231a:");
        emojisMap.put(0x1f513, ":emoji_1f513:");
        emojisMap.put(0x1f512, ":emoji_1f512:");
        emojisMap.put(0x1f50f, ":emoji_1f50f:");
        emojisMap.put(0x1f510, ":emoji_1f510:");
        emojisMap.put(0x1f511, ":emoji_1f511:");
        emojisMap.put(0x1f50e, ":emoji_1f50e:");
        emojisMap.put(0x1f4a1, ":emoji_1f4a1:");
        emojisMap.put(0x1f526, ":emoji_1f526:");
        emojisMap.put(0x1f506, ":emoji_1f506:");
        emojisMap.put(0x1f505, ":emoji_1f505:");
        emojisMap.put(0x1f50c, ":emoji_1f50c:");
        emojisMap.put(0x1f50b, ":emoji_1f50b:");
        emojisMap.put(0x1f50d, ":emoji_1f50d:");
        emojisMap.put(0x1f6c1, ":emoji_1f6c1:");
        emojisMap.put(0x1f6c0, ":emoji_1f6c0:");
        emojisMap.put(0x1f6bf, ":emoji_1f6bf:");
        emojisMap.put(0x1f6bd, ":emoji_1f6bd:");
        emojisMap.put(0x1f527, ":emoji_1f527:");
        emojisMap.put(0x1f529, ":emoji_1f529:");
        emojisMap.put(0x1f528, ":emoji_1f528:");
        emojisMap.put(0x1f6aa, ":emoji_1f6aa:");
        emojisMap.put(0x1f6ac, ":emoji_1f6ac:");
        emojisMap.put(0x1f4a3, ":emoji_1f4a3:");
        emojisMap.put(0x1f52b, ":emoji_1f52b:");
        emojisMap.put(0x1f52a, ":emoji_1f52a:");
        emojisMap.put(0x1f48a, ":emoji_1f48a:");
        emojisMap.put(0x1f489, ":emoji_1f489:");
        emojisMap.put(0x1f4b0, ":emoji_1f4b0:");
        emojisMap.put(0x1f4b4, ":emoji_1f4b4:");
        emojisMap.put(0x1f4b5, ":emoji_1f4b5:");
        emojisMap.put(0x1f4b7, ":emoji_1f4b7:");
        emojisMap.put(0x1f4b6, ":emoji_1f4b6:");
        emojisMap.put(0x1f4b3, ":emoji_1f4b3:");
        emojisMap.put(0x1f4b8, ":emoji_1f4b8:");
        emojisMap.put(0x1f4f2, ":emoji_1f4f2:");
        emojisMap.put(0x1f4e7, ":emoji_1f4e7:");
        emojisMap.put(0x1f4e5, ":emoji_1f4e5:");
        emojisMap.put(0x1f4e4, ":emoji_1f4e4:");
        emojisMap.put(0x2709, ":emoji_2709:");
        emojisMap.put(0x1f4e9, ":emoji_1f4e9:");
        emojisMap.put(0x1f4e8, ":emoji_1f4e8:");
        emojisMap.put(0x1f4ef, ":emoji_1f4ef:");
        emojisMap.put(0x1f4eb, ":emoji_1f4eb:");
        emojisMap.put(0x1f4ea, ":emoji_1f4ea:");
        emojisMap.put(0x1f4ec, ":emoji_1f4ec:");
        emojisMap.put(0x1f4ed, ":emoji_1f4ed:");
        emojisMap.put(0x1f4ee, ":emoji_1f4ee:");
        emojisMap.put(0x1f4e6, ":emoji_1f4e6:");
        emojisMap.put(0x1f4dd, ":emoji_1f4dd:");
        emojisMap.put(0x1f4c4, ":emoji_1f4c4:");
        emojisMap.put(0x1f4c3, ":emoji_1f4c3:");
        emojisMap.put(0x1f4d1, ":emoji_1f4d1:");
        emojisMap.put(0x1f4ca, ":emoji_1f4ca:");
        emojisMap.put(0x1f4c8, ":emoji_1f4c8:");
        emojisMap.put(0x1f4c9, ":emoji_1f4c9:");
        emojisMap.put(0x1f4dc, ":emoji_1f4dc:");
        emojisMap.put(0x1f4cb, ":emoji_1f4cb:");
        emojisMap.put(0x1f4c5, ":emoji_1f4c5:");
        emojisMap.put(0x1f4c6, ":emoji_1f4c6:");
        emojisMap.put(0x1f4c7, ":emoji_1f4c7:");
        emojisMap.put(0x1f4c1, ":emoji_1f4c1:");
        emojisMap.put(0x1f4c2, ":emoji_1f4c2:");
        emojisMap.put(0x2702, ":emoji_2702:");
        emojisMap.put(0x1f4cc, ":emoji_1f4cc:");
        emojisMap.put(0x1f4ce, ":emoji_1f4ce:");
        emojisMap.put(0x2712, ":emoji_2712:");
        emojisMap.put(0x270f, ":emoji_270f:");
        emojisMap.put(0x1f4cf, ":emoji_1f4cf:");
        emojisMap.put(0x1f4d0, ":emoji_1f4d0:");
        emojisMap.put(0x1f4d5, ":emoji_1f4d5:");
        emojisMap.put(0x1f4d7, ":emoji_1f4d7:");
        emojisMap.put(0x1f4d8, ":emoji_1f4d8:");
        emojisMap.put(0x1f4d9, ":emoji_1f4d9:");
        emojisMap.put(0x1f4d3, ":emoji_1f4d3:");
        emojisMap.put(0x1f4d4, ":emoji_1f4d4:");
        emojisMap.put(0x1f4d2, ":emoji_1f4d2:");
        emojisMap.put(0x1f4da, ":emoji_1f4da:");
        emojisMap.put(0x1f4d6, ":emoji_1f4d6:");
        emojisMap.put(0x1f516, ":emoji_1f516:");
        emojisMap.put(0x1f4db, ":emoji_1f4db:");
        emojisMap.put(0x1f52c, ":emoji_1f52c:");
        emojisMap.put(0x1f52d, ":emoji_1f52d:");
        emojisMap.put(0x1f4f0, ":emoji_1f4f0:");
        emojisMap.put(0x1f3a8, ":emoji_1f3a8:");
        emojisMap.put(0x1f3ac, ":emoji_1f3ac:");
        emojisMap.put(0x1f3a4, ":emoji_1f3a4:");
        emojisMap.put(0x1f3a7, ":emoji_1f3a7:");
        emojisMap.put(0x1f3bc, ":emoji_1f3bc:");
        emojisMap.put(0x1f3b5, ":emoji_1f3b5:");
        emojisMap.put(0x1f3b6, ":emoji_1f3b6:");
        emojisMap.put(0x1f3b9, ":emoji_1f3b9:");
        emojisMap.put(0x1f3bb, ":emoji_1f3bb:");
        emojisMap.put(0x1f3ba, ":emoji_1f3ba:");
        emojisMap.put(0x1f3b7, ":emoji_1f3b7:");
        emojisMap.put(0x1f3b8, ":emoji_1f3b8:");
        emojisMap.put(0x1f47e, ":emoji_1f47e:");
        emojisMap.put(0x1f3ae, ":emoji_1f3ae:");
        emojisMap.put(0x1f0cf, ":emoji_1f0cf:");
        emojisMap.put(0x1f3b4, ":emoji_1f3b4:");
        emojisMap.put(0x1f004, ":emoji_1f004:");
        emojisMap.put(0x1f3b2, ":emoji_1f3b2:");
        emojisMap.put(0x1f3af, ":emoji_1f3af:");
        emojisMap.put(0x1f3c8, ":emoji_1f3c8:");
        emojisMap.put(0x1f3c0, ":emoji_1f3c0:");
        emojisMap.put(0x26bd, ":emoji_26bd:");
        emojisMap.put(0x26be, ":emoji_26be:");
        emojisMap.put(0x1f3be, ":emoji_1f3be:");
        emojisMap.put(0x1f3b1, ":emoji_1f3b1:");
        emojisMap.put(0x1f3c9, ":emoji_1f3c9:");
        emojisMap.put(0x1f3b3, ":emoji_1f3b3:");
        emojisMap.put(0x26f3, ":emoji_26f3:");
        emojisMap.put(0x1f6b5, ":emoji_1f6b5:");
        emojisMap.put(0x1f6b4, ":emoji_1f6b4:");
        emojisMap.put(0x1f3c1, ":emoji_1f3c1:");
        emojisMap.put(0x1f3c7, ":emoji_1f3c7:");
        emojisMap.put(0x1f3c6, ":emoji_1f3c6:");
        emojisMap.put(0x1f3bf, ":emoji_1f3bf:");
        emojisMap.put(0x1f3c2, ":emoji_1f3c2:");
        emojisMap.put(0x1f3ca, ":emoji_1f3ca:");
        emojisMap.put(0x1f3c4, ":emoji_1f3c4:");
        emojisMap.put(0x1f3a3, ":emoji_1f3a3:");
        emojisMap.put(0x2615, ":emoji_2615:");
        emojisMap.put(0x1f375, ":emoji_1f375:");
        emojisMap.put(0x1f376, ":emoji_1f376:");
        emojisMap.put(0x1f37c, ":emoji_1f37c:");
        emojisMap.put(0x1f37a, ":emoji_1f37a:");
        emojisMap.put(0x1f37b, ":emoji_1f37b:");
        emojisMap.put(0x1f378, ":emoji_1f378:");
        emojisMap.put(0x1f379, ":emoji_1f379:");
        emojisMap.put(0x1f377, ":emoji_1f377:");
        emojisMap.put(0x1f374, ":emoji_1f374:");
        emojisMap.put(0x1f355, ":emoji_1f355:");
        emojisMap.put(0x1f354, ":emoji_1f354:");
        emojisMap.put(0x1f35f, ":emoji_1f35f:");
        emojisMap.put(0x1f357, ":emoji_1f357:");
        emojisMap.put(0x1f356, ":emoji_1f356:");
        emojisMap.put(0x1f35d, ":emoji_1f35d:");
        emojisMap.put(0x1f35b, ":emoji_1f35b:");
        emojisMap.put(0x1f364, ":emoji_1f364:");
        emojisMap.put(0x1f371, ":emoji_1f371:");
        emojisMap.put(0x1f363, ":emoji_1f363:");
        emojisMap.put(0x1f365, ":emoji_1f365:");
        emojisMap.put(0x1f359, ":emoji_1f359:");
        emojisMap.put(0x1f358, ":emoji_1f358:");
        emojisMap.put(0x1f35a, ":emoji_1f35a:");
        emojisMap.put(0x1f35c, ":emoji_1f35c:");
        emojisMap.put(0x1f372, ":emoji_1f372:");
        emojisMap.put(0x1f362, ":emoji_1f362:");
        emojisMap.put(0x1f361, ":emoji_1f361:");
        emojisMap.put(0x1f373, ":emoji_1f373:");
        emojisMap.put(0x1f35e, ":emoji_1f35e:");
        emojisMap.put(0x1f369, ":emoji_1f369:");
        emojisMap.put(0x1f36e, ":emoji_1f36e:");
        emojisMap.put(0x1f366, ":emoji_1f366:");
        emojisMap.put(0x1f368, ":emoji_1f368:");
        emojisMap.put(0x1f367, ":emoji_1f367:");
        emojisMap.put(0x1f382, ":emoji_1f382:");
        emojisMap.put(0x1f370, ":emoji_1f370:");
        emojisMap.put(0x1f36a, ":emoji_1f36a:");
        emojisMap.put(0x1f36b, ":emoji_1f36b:");
        emojisMap.put(0x1f36c, ":emoji_1f36c:");
        emojisMap.put(0x1f36d, ":emoji_1f36d:");
        emojisMap.put(0x1f36f, ":emoji_1f36f:");
        emojisMap.put(0x1f34e, ":emoji_1f34e:");
        emojisMap.put(0x1f34f, ":emoji_1f34f:");
        emojisMap.put(0x1f34a, ":emoji_1f34a:");
        emojisMap.put(0x1f34b, ":emoji_1f34b:");
        emojisMap.put(0x1f352, ":emoji_1f352:");
        emojisMap.put(0x1f347, ":emoji_1f347:");
        emojisMap.put(0x1f349, ":emoji_1f349:");
        emojisMap.put(0x1f353, ":emoji_1f353:");
        emojisMap.put(0x1f351, ":emoji_1f351:");
        emojisMap.put(0x1f348, ":emoji_1f348:");
        emojisMap.put(0x1f34c, ":emoji_1f34c:");
        emojisMap.put(0x1f350, ":emoji_1f350:");
        emojisMap.put(0x1f34d, ":emoji_1f34d:");
        emojisMap.put(0x1f360, ":emoji_1f360:");
        emojisMap.put(0x1f346, ":emoji_1f346:");
        emojisMap.put(0x1f345, ":emoji_1f345:");
        emojisMap.put(0x1f33d, ":emoji_1f33d:");

        // Places
        emojisMap.put(0x1f3e0, ":emoji_1f3e0:");
        emojisMap.put(0x1f3e1, ":emoji_1f3e1:");
        emojisMap.put(0x1f3eb, ":emoji_1f3eb:");
        emojisMap.put(0x1f3e2, ":emoji_1f3e2:");
        emojisMap.put(0x1f3e3, ":emoji_1f3e3:");
        emojisMap.put(0x1f3e5, ":emoji_1f3e5:");
        emojisMap.put(0x1f3e6, ":emoji_1f3e6:");
        emojisMap.put(0x1f3ea, ":emoji_1f3ea:");
        emojisMap.put(0x1f3e9, ":emoji_1f3e9:");
        emojisMap.put(0x1f3e8, ":emoji_1f3e8:");
        emojisMap.put(0x1f492, ":emoji_1f492:");
        emojisMap.put(0x26ea, ":emoji_26ea:");
        emojisMap.put(0x1f3ec, ":emoji_1f3ec:");
        emojisMap.put(0x1f3e4, ":emoji_1f3e4:");
        emojisMap.put(0x1f307, ":emoji_1f307:");
        emojisMap.put(0x1f306, ":emoji_1f306:");
        emojisMap.put(0x1f3ef, ":emoji_1f3ef:");
        emojisMap.put(0x1f3f0, ":emoji_1f3f0:");
        emojisMap.put(0x26fa, ":emoji_26fa:");
        emojisMap.put(0x1f3ed, ":emoji_1f3ed:");
        emojisMap.put(0x1f5fc, ":emoji_1f5fc:");
        emojisMap.put(0x1f5fe, ":emoji_1f5fe:");
        emojisMap.put(0x1f5fb, ":emoji_1f5fb:");
        emojisMap.put(0x1f304, ":emoji_1f304:");
        emojisMap.put(0x1f305, ":emoji_1f305:");
        emojisMap.put(0x1f303, ":emoji_1f303:");
        emojisMap.put(0x1f5fd, ":emoji_1f5fd:");
        emojisMap.put(0x1f309, ":emoji_1f309:");
        emojisMap.put(0x1f3a0, ":emoji_1f3a0:");
        emojisMap.put(0x1f3a1, ":emoji_1f3a1:");
        emojisMap.put(0x26f2, ":emoji_26f2:");
        emojisMap.put(0x1f3a2, ":emoji_1f3a2:");
        emojisMap.put(0x1f6a2, ":emoji_1f6a2:");
        emojisMap.put(0x26f5, ":emoji_26f5:");
        emojisMap.put(0x1f6a4, ":emoji_1f6a4:");
        emojisMap.put(0x1f6a3, ":emoji_1f6a3:");
        emojisMap.put(0x2693, ":emoji_2693:");
        emojisMap.put(0x1f680, ":emoji_1f680:");
        emojisMap.put(0x2708, ":emoji_2708:");
        emojisMap.put(0x1f4ba, ":emoji_1f4ba:");
        emojisMap.put(0x1f681, ":emoji_1f681:");
        emojisMap.put(0x1f682, ":emoji_1f682:");
        emojisMap.put(0x1f68a, ":emoji_1f68a:");
        emojisMap.put(0x1f689, ":emoji_1f689:");
        emojisMap.put(0x1f69e, ":emoji_1f69e:");
        emojisMap.put(0x1f686, ":emoji_1f686:");
        emojisMap.put(0x1f684, ":emoji_1f684:");
        emojisMap.put(0x1f685, ":emoji_1f685:");
        emojisMap.put(0x1f688, ":emoji_1f688:");
        emojisMap.put(0x1f687, ":emoji_1f687:");
        emojisMap.put(0x1f69d, ":emoji_1f69d:");
        emojisMap.put(0x1f68b, ":emoji_1f68b:");
        emojisMap.put(0x1f683, ":emoji_1f683:");
        emojisMap.put(0x1f68e, ":emoji_1f68e:");
        emojisMap.put(0x1f68c, ":emoji_1f68c:");
        emojisMap.put(0x1f68d, ":emoji_1f68d:");
        emojisMap.put(0x1f699, ":emoji_1f699:");
        emojisMap.put(0x1f698, ":emoji_1f698:");
        emojisMap.put(0x1f697, ":emoji_1f697:");
        emojisMap.put(0x1f695, ":emoji_1f695:");
        emojisMap.put(0x1f696, ":emoji_1f696:");
        emojisMap.put(0x1f69b, ":emoji_1f69b:");
        emojisMap.put(0x1f69a, ":emoji_1f69a:");
        emojisMap.put(0x1f6a8, ":emoji_1f6a8:");
        emojisMap.put(0x1f693, ":emoji_1f693:");
        emojisMap.put(0x1f694, ":emoji_1f694:");
        emojisMap.put(0x1f692, ":emoji_1f692:");
        emojisMap.put(0x1f691, ":emoji_1f691:");
        emojisMap.put(0x1f690, ":emoji_1f690:");
        emojisMap.put(0x1f6b2, ":emoji_1f6b2:");
        emojisMap.put(0x1f6a1, ":emoji_1f6a1:");
        emojisMap.put(0x1f69f, ":emoji_1f69f:");
        emojisMap.put(0x1f6a0, ":emoji_1f6a0:");
        emojisMap.put(0x1f69c, ":emoji_1f69c:");
        emojisMap.put(0x1f488, ":emoji_1f488:");
        emojisMap.put(0x1f68f, ":emoji_1f68f:");
        emojisMap.put(0x1f3ab, ":emoji_1f3ab:");
        emojisMap.put(0x1f6a6, ":emoji_1f6a6:");
        emojisMap.put(0x1f6a5, ":emoji_1f6a5:");
        emojisMap.put(0x26a0, ":emoji_26a0:");
        emojisMap.put(0x1f6a7, ":emoji_1f6a7:");
        emojisMap.put(0x1f530, ":emoji_1f530:");
        emojisMap.put(0x26fd, ":emoji_26fd:");
        emojisMap.put(0x1f3ee, ":emoji_1f3ee:");
        emojisMap.put(0x1f3b0, ":emoji_1f3b0:");
        emojisMap.put(0x2668, ":emoji_2668:");
        emojisMap.put(0x1f5ff, ":emoji_1f5ff:");
        emojisMap.put(0x1f3aa, ":emoji_1f3aa:");
        emojisMap.put(0x1f3ad, ":emoji_1f3ad:");
        emojisMap.put(0x1f4cd, ":emoji_1f4cd:");
        emojisMap.put(0x1f6a9, ":emoji_1f6a9:");

        // Symbols
        emojisMap.put(0x1f51f, ":emoji_1f51f:");
        emojisMap.put(0x1f522, ":emoji_1f522:");
        emojisMap.put(0x1f523, ":emoji_1f523:");
        emojisMap.put(0x2b06, ":emoji_2b06:");
        emojisMap.put(0x2b07, ":emoji_2b07:");
        emojisMap.put(0x2b05, ":emoji_2b05:");
        emojisMap.put(0x27a1, ":emoji_27a1:");
        emojisMap.put(0x1f520, ":emoji_1f520:");
        emojisMap.put(0x1f521, ":emoji_1f521:");
        emojisMap.put(0x1f524, ":emoji_1f524:");
        emojisMap.put(0x2197, ":emoji_2197:");
        emojisMap.put(0x2196, ":emoji_2196:");
        emojisMap.put(0x2198, ":emoji_2198:");
        emojisMap.put(0x2199, ":emoji_2199:");
        emojisMap.put(0x2194, ":emoji_2194:");
        emojisMap.put(0x2195, ":emoji_2195:");
        emojisMap.put(0x1f504, ":emoji_1f504:");
        emojisMap.put(0x25c0, ":emoji_25c0:");
        emojisMap.put(0x25b6, ":emoji_25b6:");
        emojisMap.put(0x1f53c, ":emoji_1f53c:");
        emojisMap.put(0x1f53d, ":emoji_1f53d:");
        emojisMap.put(0x21a9, ":emoji_21a9:");
        emojisMap.put(0x21aa, ":emoji_21aa:");
        emojisMap.put(0x2139, ":emoji_2139:");
        emojisMap.put(0x23ea, ":emoji_23ea:");
        emojisMap.put(0x23e9, ":emoji_23e9:");
        emojisMap.put(0x23eb, ":emoji_23eb:");
        emojisMap.put(0x23ec, ":emoji_23ec:");
        emojisMap.put(0x2935, ":emoji_2935:");
        emojisMap.put(0x2934, ":emoji_2934:");
        emojisMap.put(0x1f197, ":emoji_1f197:");
        emojisMap.put(0x1f500, ":emoji_1f500:");
        emojisMap.put(0x1f501, ":emoji_1f501:");
        emojisMap.put(0x1f502, ":emoji_1f502:");
        emojisMap.put(0x1f195, ":emoji_1f195:");
        emojisMap.put(0x1f199, ":emoji_1f199:");
        emojisMap.put(0x1f192, ":emoji_1f192:");
        emojisMap.put(0x1f193, ":emoji_1f193:");
        emojisMap.put(0x1f196, ":emoji_1f196:");
        emojisMap.put(0x1f4f6, ":emoji_1f4f6:");
        emojisMap.put(0x1f3a6, ":emoji_1f3a6:");
        emojisMap.put(0x1f201, ":emoji_1f201:");
        emojisMap.put(0x1f22f, ":emoji_1f22f:");
        emojisMap.put(0x1f233, ":emoji_1f233:");
        emojisMap.put(0x1f235, ":emoji_1f235:");
        emojisMap.put(0x1f234, ":emoji_1f234:");
        emojisMap.put(0x1f232, ":emoji_1f232:");
        emojisMap.put(0x1f250, ":emoji_1f250:");
        emojisMap.put(0x1f239, ":emoji_1f239:");
        emojisMap.put(0x1f23a, ":emoji_1f23a:");
        emojisMap.put(0x1f236, ":emoji_1f236:");
        emojisMap.put(0x1f21a, ":emoji_1f21a:");
        emojisMap.put(0x1f6bb, ":emoji_1f6bb:");
        emojisMap.put(0x1f6b9, ":emoji_1f6b9:");
        emojisMap.put(0x1f6ba, ":emoji_1f6ba:");
        emojisMap.put(0x1f6bc, ":emoji_1f6bc:");
        emojisMap.put(0x1f6be, ":emoji_1f6be:");
        emojisMap.put(0x1f6b0, ":emoji_1f6b0:");
        emojisMap.put(0x1f6ae, ":emoji_1f6ae:");
        emojisMap.put(0x1f17f, ":emoji_1f17f:");
        emojisMap.put(0x267f, ":emoji_267f:");
        emojisMap.put(0x1f6ad, ":emoji_1f6ad:");
        emojisMap.put(0x1f237, ":emoji_1f237:");
        emojisMap.put(0x1f238, ":emoji_1f238:");
        emojisMap.put(0x1f202, ":emoji_1f202:");
        emojisMap.put(0x24c2, ":emoji_24c2:");
        emojisMap.put(0x1f6c2, ":emoji_1f6c2:");
        emojisMap.put(0x1f6c4, ":emoji_1f6c4:");
        emojisMap.put(0x1f6c5, ":emoji_1f6c5:");
        emojisMap.put(0x1f6c3, ":emoji_1f6c3:");
        emojisMap.put(0x1f251, ":emoji_1f251:");
        emojisMap.put(0x3299, ":emoji_3299:");
        emojisMap.put(0x3297, ":emoji_3297:");
        emojisMap.put(0x1f191, ":emoji_1f191:");
        emojisMap.put(0x1f198, ":emoji_1f198:");
        emojisMap.put(0x1f194, ":emoji_1f194:");
        emojisMap.put(0x1f6ab, ":emoji_1f6ab:");
        emojisMap.put(0x1f51e, ":emoji_1f51e:");
        emojisMap.put(0x1f4f5, ":emoji_1f4f5:");
        emojisMap.put(0x1f6af, ":emoji_1f6af:");
        emojisMap.put(0x1f6b1, ":emoji_1f6b1:");
        emojisMap.put(0x1f6b3, ":emoji_1f6b3:");
        emojisMap.put(0x1f6b7, ":emoji_1f6b7:");
        emojisMap.put(0x1f6b8, ":emoji_1f6b8:");
        emojisMap.put(0x26d4, ":emoji_26d4:");
        emojisMap.put(0x2733, ":emoji_2733:");
        emojisMap.put(0x2747, ":emoji_2747:");
        emojisMap.put(0x274e, ":emoji_274e:");
        emojisMap.put(0x2705, ":emoji_2705:");
        emojisMap.put(0x2734, ":emoji_2734:");
        emojisMap.put(0x1f49f, ":emoji_1f49f:");
        emojisMap.put(0x1f19a, ":emoji_1f19a:");
        emojisMap.put(0x1f4f3, ":emoji_1f4f3:");
        emojisMap.put(0x1f4f4, ":emoji_1f4f4:");
        emojisMap.put(0x1f170, ":emoji_1f170:");
        emojisMap.put(0x1f171, ":emoji_1f171:");
        emojisMap.put(0x1f18e, ":emoji_1f18e:");
        emojisMap.put(0x1f17e, ":emoji_1f17e:");
        emojisMap.put(0x1f4a0, ":emoji_1f4a0:");
        emojisMap.put(0x27bf, ":emoji_27bf:");
        emojisMap.put(0x267b, ":emoji_267b:");
        emojisMap.put(0x2648, ":emoji_2648:");
        emojisMap.put(0x2649, ":emoji_2649:");
        emojisMap.put(0x264a, ":emoji_264a:");
        emojisMap.put(0x264b, ":emoji_264b:");
        emojisMap.put(0x264c, ":emoji_264c:");
        emojisMap.put(0x264d, ":emoji_264d:");
        emojisMap.put(0x264e, ":emoji_264e:");
        emojisMap.put(0x264f, ":emoji_264f:");
        emojisMap.put(0x2650, ":emoji_2650:");
        emojisMap.put(0x2651, ":emoji_2651:");
        emojisMap.put(0x2652, ":emoji_2652:");
        emojisMap.put(0x2653, ":emoji_2653:");
        emojisMap.put(0x26ce, ":emoji_26ce:");
        emojisMap.put(0x1f52f, ":emoji_1f52f:");
        emojisMap.put(0x1f3e7, ":emoji_1f3e7:");
        emojisMap.put(0x1f4b9, ":emoji_1f4b9:");
        emojisMap.put(0x1f4b2, ":emoji_1f4b2:");
        emojisMap.put(0x1f4b1, ":emoji_1f4b1:");
        emojisMap.put(0x00a9, ":emoji_00a9:");
        emojisMap.put(0x00ae, ":emoji_00ae:");
        emojisMap.put(0x2122, ":emoji_2122:");
        emojisMap.put(0x274c, ":emoji_274c:");
        emojisMap.put(0x203c, ":emoji_203c:");
        emojisMap.put(0x2049, ":emoji_2049:");
        emojisMap.put(0x2757, ":emoji_2757:");
        emojisMap.put(0x2753, ":emoji_2753:");
        emojisMap.put(0x2755, ":emoji_2755:");
        emojisMap.put(0x2754, ":emoji_2754:");
        emojisMap.put(0x2b55, ":emoji_2b55:");
        emojisMap.put(0x1f51d, ":emoji_1f51d:");
        emojisMap.put(0x1f51a, ":emoji_1f51a:");
        emojisMap.put(0x1f519, ":emoji_1f519:");
        emojisMap.put(0x1f51b, ":emoji_1f51b:");
        emojisMap.put(0x1f51c, ":emoji_1f51c:");
        emojisMap.put(0x1f503, ":emoji_1f503:");
        emojisMap.put(0x1f55b, ":emoji_1f55b:");
        emojisMap.put(0x1f567, ":emoji_1f567:");
        emojisMap.put(0x1f550, ":emoji_1f550:");
        emojisMap.put(0x1f55c, ":emoji_1f55c:");
        emojisMap.put(0x1f551, ":emoji_1f551:");
        emojisMap.put(0x1f55d, ":emoji_1f55d:");
        emojisMap.put(0x1f552, ":emoji_1f552:");
        emojisMap.put(0x1f55e, ":emoji_1f55e:");
        emojisMap.put(0x1f553, ":emoji_1f553:");
        emojisMap.put(0x1f55f, ":emoji_1f55f:");
        emojisMap.put(0x1f554, ":emoji_1f554:");
        emojisMap.put(0x1f560, ":emoji_1f560:");
        emojisMap.put(0x1f555, ":emoji_1f555:");
        emojisMap.put(0x1f556, ":emoji_1f556:");
        emojisMap.put(0x1f557, ":emoji_1f557:");
        emojisMap.put(0x1f558, ":emoji_1f558:");
        emojisMap.put(0x1f559, ":emoji_1f559:");
        emojisMap.put(0x1f55a, ":emoji_1f55a:");
        emojisMap.put(0x1f561, ":emoji_1f561:");
        emojisMap.put(0x1f562, ":emoji_1f562:");
        emojisMap.put(0x1f563, ":emoji_1f563:");
        emojisMap.put(0x1f564, ":emoji_1f564:");
        emojisMap.put(0x1f565, ":emoji_1f565:");
        emojisMap.put(0x1f566, ":emoji_1f566:");
        emojisMap.put(0x2716, ":emoji_2716:");
        emojisMap.put(0x2795, ":emoji_2795:");
        emojisMap.put(0x2796, ":emoji_2796:");
        emojisMap.put(0x2797, ":emoji_2797:");
        emojisMap.put(0x2660, ":emoji_2660:");
        emojisMap.put(0x2665, ":emoji_2665:");
        emojisMap.put(0x2663, ":emoji_2663:");
        emojisMap.put(0x2666, ":emoji_2666:");
        emojisMap.put(0x1f4ae, ":emoji_1f4ae:");
        emojisMap.put(0x1f4af, ":emoji_1f4af:");
        emojisMap.put(0x2714, ":emoji_2714:");
        emojisMap.put(0x2611, ":emoji_2611:");
        emojisMap.put(0x1f518, ":emoji_1f518:");
        emojisMap.put(0x1f517, ":emoji_1f517:");
        emojisMap.put(0x27b0, ":emoji_27b0:");
        emojisMap.put(0x3030, ":emoji_3030:");
        emojisMap.put(0x303d, ":emoji_303d:");
        emojisMap.put(0x1f531, ":emoji_1f531:");
        emojisMap.put(0x25fc, ":emoji_25fc:");
        emojisMap.put(0x25fb, ":emoji_25fb:");
        emojisMap.put(0x25fe, ":emoji_25fe:");
        emojisMap.put(0x25fd, ":emoji_25fd:");
        emojisMap.put(0x25aa, ":emoji_25aa:");
        emojisMap.put(0x25ab, ":emoji_25ab:");
        emojisMap.put(0x1f53a, ":emoji_1f53a:");
        emojisMap.put(0x1f532, ":emoji_1f532:");
        emojisMap.put(0x1f533, ":emoji_1f533:");
        emojisMap.put(0x26ab, ":emoji_26ab:");
        emojisMap.put(0x26aa, ":emoji_26aa:");
        emojisMap.put(0x1f534, ":emoji_1f534:");
        emojisMap.put(0x1f535, ":emoji_1f535:");
        emojisMap.put(0x1f53b, ":emoji_1f53b:");
        emojisMap.put(0x2b1c, ":emoji_2b1c:");
        emojisMap.put(0x2b1b, ":emoji_2b1b:");
        emojisMap.put(0x1f536, ":emoji_1f536:");
        emojisMap.put(0x1f537, ":emoji_1f537:");
        emojisMap.put(0x1f538, ":emoji_1f538:");
        emojisMap.put(0x1f539, ":emoji_1f539:");

        //SoftBank

        emojisMap.put(0xe001, ":emoji_1f466:");
        emojisMap.put(0xe002, ":emoji_1f467:");
        emojisMap.put(0xe003, ":emoji_1f48b:");
        emojisMap.put(0xe004, ":emoji_1f468:");
        emojisMap.put(0xe005, ":emoji_1f469:");
        emojisMap.put(0xe006, ":emoji_1f455:");
        emojisMap.put(0xe007, ":emoji_1f45e:");
        emojisMap.put(0xe008, ":emoji_1f4f7:");
        emojisMap.put(0xe009, ":emoji_1f4de:");
        emojisMap.put(0xe00a, ":emoji_1f4f1:");
        emojisMap.put(0xe00b, ":emoji_1f4e0:");
        emojisMap.put(0xe00c, ":emoji_1f4bb:");
        emojisMap.put(0xe00d, ":emoji_1f44a:");
        emojisMap.put(0xe00e, ":emoji_1f44d:");
        emojisMap.put(0xe00f, ":emoji_261d:");
        emojisMap.put(0xe010, ":emoji_270a:");
        emojisMap.put(0xe011, ":emoji_270c:");
        emojisMap.put(0xe012, ":emoji_1f64b:");
        emojisMap.put(0xe013, ":emoji_1f3bf:");
        emojisMap.put(0xe014, ":emoji_26f3:");
        emojisMap.put(0xe015, ":emoji_1f3be:");
        emojisMap.put(0xe016, ":emoji_26be:");
        emojisMap.put(0xe017, ":emoji_1f3c4:");
        emojisMap.put(0xe018, ":emoji_26bd:");
        emojisMap.put(0xe019, ":emoji_1f3a3:");
        emojisMap.put(0xe01a, ":emoji_1f434:");
        emojisMap.put(0xe01b, ":emoji_1f697:");
        emojisMap.put(0xe01c, ":emoji_26f5:");
        emojisMap.put(0xe01d, ":emoji_2708:");
        emojisMap.put(0xe01e, ":emoji_1f683:");
        emojisMap.put(0xe01f, ":emoji_1f685:");
        emojisMap.put(0xe020, ":emoji_2753:");
        emojisMap.put(0xe021, ":emoji_2757:");
        emojisMap.put(0xe022, ":emoji_2764:");
        emojisMap.put(0xe023, ":emoji_1f494:");
        emojisMap.put(0xe024, ":emoji_1f550:");
        emojisMap.put(0xe025, ":emoji_1f551:");
        emojisMap.put(0xe026, ":emoji_1f552:");
        emojisMap.put(0xe027, ":emoji_1f553:");
        emojisMap.put(0xe028, ":emoji_1f554:");
        emojisMap.put(0xe029, ":emoji_1f555:");
        emojisMap.put(0xe02a, ":emoji_1f556:");
        emojisMap.put(0xe02b, ":emoji_1f557:");
        emojisMap.put(0xe02c, ":emoji_1f558:");
        emojisMap.put(0xe02d, ":emoji_1f559:");
        emojisMap.put(0xe02e, ":emoji_1f55a:");
        emojisMap.put(0xe02f, ":emoji_1f55b:");
        emojisMap.put(0xe030, ":emoji_1f338:");
        emojisMap.put(0xe031, ":emoji_1f531:");
        emojisMap.put(0xe032, ":emoji_1f339:");
        emojisMap.put(0xe033, ":emoji_1f384:");
        emojisMap.put(0xe034, ":emoji_1f48d:");
        emojisMap.put(0xe035, ":emoji_1f48e:");
        emojisMap.put(0xe036, ":emoji_1f3e0:");
        emojisMap.put(0xe037, ":emoji_26ea:");
        emojisMap.put(0xe038, ":emoji_1f3e2:");
        emojisMap.put(0xe039, ":emoji_1f689:");
        emojisMap.put(0xe03a, ":emoji_26fd:");
        emojisMap.put(0xe03b, ":emoji_1f5fb:");
        emojisMap.put(0xe03c, ":emoji_1f3a4:");
        emojisMap.put(0xe03d, ":emoji_1f3a5:");
        emojisMap.put(0xe03e, ":emoji_1f3b5:");
        emojisMap.put(0xe03f, ":emoji_1f511:");
        emojisMap.put(0xe040, ":emoji_1f3b7:");
        emojisMap.put(0xe041, ":emoji_1f3b8:");
        emojisMap.put(0xe042, ":emoji_1f3ba:");
        emojisMap.put(0xe043, ":emoji_1f374:");
        emojisMap.put(0xe044, ":emoji_1f377:");
        emojisMap.put(0xe045, ":emoji_2615:");
        emojisMap.put(0xe046, ":emoji_1f370:");
        emojisMap.put(0xe047, ":emoji_1f37a:");
        emojisMap.put(0xe048, ":emoji_26c4:");
        emojisMap.put(0xe049, ":emoji_2601:");
        emojisMap.put(0xe04a, ":emoji_2600:");
        emojisMap.put(0xe04b, ":emoji_2614:");
        emojisMap.put(0xe04c, ":emoji_1f313:");
        emojisMap.put(0xe04d, ":emoji_1f304:");
        emojisMap.put(0xe04e, ":emoji_1f47c:");
        emojisMap.put(0xe04f, ":emoji_1f431:");
        emojisMap.put(0xe050, ":emoji_1f42f:");
        emojisMap.put(0xe051, ":emoji_1f43b:");
        emojisMap.put(0xe052, ":emoji_1f429:");
        emojisMap.put(0xe053, ":emoji_1f42d:");
        emojisMap.put(0xe054, ":emoji_1f433:");
        emojisMap.put(0xe055, ":emoji_1f427:");
        emojisMap.put(0xe056, ":emoji_1f60a:");
        emojisMap.put(0xe057, ":emoji_1f603:");
        emojisMap.put(0xe058, ":emoji_1f61e:");
        emojisMap.put(0xe059, ":emoji_1f620:");
        emojisMap.put(0xe05a, ":emoji_1f4a9:");
        emojisMap.put(0xe101, ":emoji_1f4ea:");
        emojisMap.put(0xe102, ":emoji_1f4ee:");
        emojisMap.put(0xe103, ":emoji_1f4e7:");
        emojisMap.put(0xe104, ":emoji_1f4f2:");
        emojisMap.put(0xe105, ":emoji_1f61c:");
        emojisMap.put(0xe106, ":emoji_1f60d:");
        emojisMap.put(0xe107, ":emoji_1f631:");
        emojisMap.put(0xe108, ":emoji_1f613:");
        emojisMap.put(0xe109, ":emoji_1f435:");
        emojisMap.put(0xe10a, ":emoji_1f419:");
        emojisMap.put(0xe10b, ":emoji_1f437:");
        emojisMap.put(0xe10c, ":emoji_1f47d:");
        emojisMap.put(0xe10d, ":emoji_1f680:");
        emojisMap.put(0xe10e, ":emoji_1f451:");
        emojisMap.put(0xe10f, ":emoji_1f4a1:");
        emojisMap.put(0xe110, ":emoji_1f331:");
        emojisMap.put(0xe111, ":emoji_1f48f:");
        emojisMap.put(0xe112, ":emoji_1f381:");
        emojisMap.put(0xe113, ":emoji_1f52b:");
        emojisMap.put(0xe114, ":emoji_1f50d:");
        emojisMap.put(0xe115, ":emoji_1f3c3:");
        emojisMap.put(0xe116, ":emoji_1f528:");
        emojisMap.put(0xe117, ":emoji_1f386:");
        emojisMap.put(0xe118, ":emoji_1f341:");
        emojisMap.put(0xe119, ":emoji_1f342:");
        emojisMap.put(0xe11a, ":emoji_1f47f:");
        emojisMap.put(0xe11b, ":emoji_1f47b:");
        emojisMap.put(0xe11c, ":emoji_1f480:");
        emojisMap.put(0xe11d, ":emoji_1f525:");
        emojisMap.put(0xe11e, ":emoji_1f4bc:");
        emojisMap.put(0xe11f, ":emoji_1f4ba:");
        emojisMap.put(0xe120, ":emoji_1f354:");
        emojisMap.put(0xe121, ":emoji_26f2:");
        emojisMap.put(0xe122, ":emoji_26fa:");
        emojisMap.put(0xe123, ":emoji_2668:");
        emojisMap.put(0xe124, ":emoji_1f3a1:");
        emojisMap.put(0xe125, ":emoji_1f3ab:");
        emojisMap.put(0xe126, ":emoji_1f4bf:");
        emojisMap.put(0xe127, ":emoji_1f4c0:");
        emojisMap.put(0xe128, ":emoji_1f4fb:");
        emojisMap.put(0xe129, ":emoji_1f4fc:");
        emojisMap.put(0xe12a, ":emoji_1f4fa:");
        emojisMap.put(0xe12b, ":emoji_1f47e:");
        emojisMap.put(0xe12c, ":emoji_303d:");
        emojisMap.put(0xe12d, ":emoji_1f004:");
        emojisMap.put(0xe12e, ":emoji_1f19a:");
        emojisMap.put(0xe12f, ":emoji_1f4b0:");
        emojisMap.put(0xe130, ":emoji_1f3af:");
        emojisMap.put(0xe131, ":emoji_1f3c6:");
        emojisMap.put(0xe132, ":emoji_1f3c1:");
        emojisMap.put(0xe133, ":emoji_1f3b0:");
        emojisMap.put(0xe134, ":emoji_1f40e:");
        emojisMap.put(0xe135, ":emoji_1f6a4:");
        emojisMap.put(0xe136, ":emoji_1f6b2:");
        emojisMap.put(0xe137, ":emoji_1f6a7:");
        emojisMap.put(0xe138, ":emoji_1f6b9:");
        emojisMap.put(0xe139, ":emoji_1f6ba:");
        emojisMap.put(0xe13a, ":emoji_1f6bc:");
        emojisMap.put(0xe13b, ":emoji_1f489:");
        emojisMap.put(0xe13c, ":emoji_1f4a4:");
        emojisMap.put(0xe13d, ":emoji_26a1:");
        emojisMap.put(0xe13e, ":emoji_1f460:");
        emojisMap.put(0xe13f, ":emoji_1f6c0:");
        emojisMap.put(0xe140, ":emoji_1f6bd:");
        emojisMap.put(0xe141, ":emoji_1f50a:");
        emojisMap.put(0xe142, ":emoji_1f4e2:");
        emojisMap.put(0xe143, ":emoji_1f38c:");
        emojisMap.put(0xe144, ":emoji_1f50f:");
        emojisMap.put(0xe145, ":emoji_1f513:");
        emojisMap.put(0xe146, ":emoji_1f306:");
        emojisMap.put(0xe147, ":emoji_1f373:");
        emojisMap.put(0xe148, ":emoji_1f4c7:");
        emojisMap.put(0xe149, ":emoji_1f4b1:");
        emojisMap.put(0xe14a, ":emoji_1f4b9:");
        emojisMap.put(0xe14b, ":emoji_1f4e1:");
        emojisMap.put(0xe14c, ":emoji_1f4aa:");
        emojisMap.put(0xe14d, ":emoji_1f3e6:");
        emojisMap.put(0xe14e, ":emoji_1f6a5:");
        emojisMap.put(0xe14f, ":emoji_1f17f:");
        emojisMap.put(0xe150, ":emoji_1f68f:");
        emojisMap.put(0xe151, ":emoji_1f6bb:");
        emojisMap.put(0xe152, ":emoji_1f46e:");
        emojisMap.put(0xe153, ":emoji_1f3e3:");
        emojisMap.put(0xe154, ":emoji_1f3e7:");
        emojisMap.put(0xe155, ":emoji_1f3e5:");
        emojisMap.put(0xe156, ":emoji_1f3ea:");
        emojisMap.put(0xe157, ":emoji_1f3eb:");
        emojisMap.put(0xe158, ":emoji_1f3e8:");
        emojisMap.put(0xe159, ":emoji_1f68c:");
        emojisMap.put(0xe15a, ":emoji_1f695:");
        emojisMap.put(0xe201, ":emoji_1f6b6:");
        emojisMap.put(0xe202, ":emoji_1f6a2:");
        emojisMap.put(0xe203, ":emoji_1f201:");
        emojisMap.put(0xe204, ":emoji_1f49f:");
        emojisMap.put(0xe205, ":emoji_2734:");
        emojisMap.put(0xe206, ":emoji_2733:");
        emojisMap.put(0xe207, ":emoji_1f51e:");
        emojisMap.put(0xe208, ":emoji_1f6ad:");
        emojisMap.put(0xe209, ":emoji_1f530:");
        emojisMap.put(0xe20a, ":emoji_267f:");
        emojisMap.put(0xe20b, ":emoji_1f4f6:");
        emojisMap.put(0xe20c, ":emoji_2665:");
        emojisMap.put(0xe20d, ":emoji_2666:");
        emojisMap.put(0xe20e, ":emoji_2660:");
        emojisMap.put(0xe20f, ":emoji_2663:");
        emojisMap.put(0xe210, ":emoji_0023:");
        emojisMap.put(0xe211, ":emoji_27bf:");
        emojisMap.put(0xe212, ":emoji_1f195:");
        emojisMap.put(0xe213, ":emoji_1f199:");
        emojisMap.put(0xe214, ":emoji_1f192:");
        emojisMap.put(0xe215, ":emoji_1f236:");
        emojisMap.put(0xe216, ":emoji_1f21a:");
        emojisMap.put(0xe217, ":emoji_1f237:");
        emojisMap.put(0xe218, ":emoji_1f238:");
        emojisMap.put(0xe219, ":emoji_1f534:");
        emojisMap.put(0xe21a, ":emoji_1f532:");
        emojisMap.put(0xe21b, ":emoji_1f533:");
        emojisMap.put(0xe21c, ":emoji_0031:");
        emojisMap.put(0xe21d, ":emoji_0032:");
        emojisMap.put(0xe21e, ":emoji_0033:");
        emojisMap.put(0xe21f, ":emoji_0034:");
        emojisMap.put(0xe220, ":emoji_0035:");
        emojisMap.put(0xe221, ":emoji_0036:");
        emojisMap.put(0xe222, ":emoji_0037:");
        emojisMap.put(0xe223, ":emoji_0038:");
        emojisMap.put(0xe224, ":emoji_0039:");
        emojisMap.put(0xe225, ":emoji_0030:");
        emojisMap.put(0xe226, ":emoji_1f250:");
        emojisMap.put(0xe227, ":emoji_1f239:");
        emojisMap.put(0xe228, ":emoji_1f202:");
        emojisMap.put(0xe229, ":emoji_1f194:");
        emojisMap.put(0xe22a, ":emoji_1f235:");
        emojisMap.put(0xe22b, ":emoji_1f233:");
        emojisMap.put(0xe22c, ":emoji_1f22f:");
        emojisMap.put(0xe22d, ":emoji_1f23a:");
        emojisMap.put(0xe22e, ":emoji_1f446:");
        emojisMap.put(0xe22f, ":emoji_1f447:");
        emojisMap.put(0xe230, ":emoji_1f448:");
        emojisMap.put(0xe231, ":emoji_1f449:");
        emojisMap.put(0xe232, ":emoji_2b06:");
        emojisMap.put(0xe233, ":emoji_2b07:");
        emojisMap.put(0xe234, ":emoji_27a1:");
        emojisMap.put(0xe235, ":emoji_1f519:");
        emojisMap.put(0xe236, ":emoji_2197:");
        emojisMap.put(0xe237, ":emoji_2196:");
        emojisMap.put(0xe238, ":emoji_2198:");
        emojisMap.put(0xe239, ":emoji_2199:");
        emojisMap.put(0xe23a, ":emoji_25b6:");
        emojisMap.put(0xe23b, ":emoji_25c0:");
        emojisMap.put(0xe23c, ":emoji_23e9:");
        emojisMap.put(0xe23d, ":emoji_23ea:");
        emojisMap.put(0xe23e, ":emoji_1f52e:");
        emojisMap.put(0xe23f, ":emoji_2648:");
        emojisMap.put(0xe240, ":emoji_2649:");
        emojisMap.put(0xe241, ":emoji_264a:");
        emojisMap.put(0xe242, ":emoji_264b:");
        emojisMap.put(0xe243, ":emoji_264c:");
        emojisMap.put(0xe244, ":emoji_264d:");
        emojisMap.put(0xe245, ":emoji_264e:");
        emojisMap.put(0xe246, ":emoji_264f:");
        emojisMap.put(0xe247, ":emoji_2650:");
        emojisMap.put(0xe248, ":emoji_2651:");
        emojisMap.put(0xe249, ":emoji_2652:");
        emojisMap.put(0xe24a, ":emoji_2653:");
        emojisMap.put(0xe24b, ":emoji_26ce:");
        emojisMap.put(0xe24c, ":emoji_1f51d:");
        emojisMap.put(0xe24d, ":emoji_1f197:");
        emojisMap.put(0xe24e, ":emoji_00a9:");
        emojisMap.put(0xe24f, ":emoji_00ae:");
        emojisMap.put(0xe250, ":emoji_1f4f3:");
        emojisMap.put(0xe251, ":emoji_1f4f4:");
        emojisMap.put(0xe252, ":emoji_26a0:");
        emojisMap.put(0xe253, ":emoji_1f481:");
        emojisMap.put(0xe301, ":emoji_1f4c3:");
        emojisMap.put(0xe302, ":emoji_1f454:");
        emojisMap.put(0xe303, ":emoji_1f33a:");
        emojisMap.put(0xe304, ":emoji_1f337:");
        emojisMap.put(0xe305, ":emoji_1f33b:");
        emojisMap.put(0xe306, ":emoji_1f490:");
        emojisMap.put(0xe307, ":emoji_1f334:");
        emojisMap.put(0xe308, ":emoji_1f335:");
        emojisMap.put(0xe309, ":emoji_1f6be:");
        emojisMap.put(0xe30a, ":emoji_1f3a7:");
        emojisMap.put(0xe30b, ":emoji_1f376:");
        emojisMap.put(0xe30c, ":emoji_1f37b:");
        emojisMap.put(0xe30d, ":emoji_3297:");
        emojisMap.put(0xe30e, ":emoji_1f6ac:");
        emojisMap.put(0xe30f, ":emoji_1f48a:");
        emojisMap.put(0xe310, ":emoji_1f388:");
        emojisMap.put(0xe311, ":emoji_1f4a3:");
        emojisMap.put(0xe312, ":emoji_1f389:");
        emojisMap.put(0xe313, ":emoji_2702:");
        emojisMap.put(0xe314, ":emoji_1f380:");
        emojisMap.put(0xe315, ":emoji_3299:");
        emojisMap.put(0xe316, ":emoji_1f4bd:");
        emojisMap.put(0xe317, ":emoji_1f4e3:");
        emojisMap.put(0xe318, ":emoji_1f452:");
        emojisMap.put(0xe319, ":emoji_1f457:");
        emojisMap.put(0xe31a, ":emoji_1f461:");
        emojisMap.put(0xe31b, ":emoji_1f462:");
        emojisMap.put(0xe31c, ":emoji_1f484:");
        emojisMap.put(0xe31d, ":emoji_1f485:");
        emojisMap.put(0xe31e, ":emoji_1f486:");
        emojisMap.put(0xe31f, ":emoji_1f487:");
        emojisMap.put(0xe320, ":emoji_1f488:");
        emojisMap.put(0xe321, ":emoji_1f458:");
        emojisMap.put(0xe322, ":emoji_1f459:");
        emojisMap.put(0xe323, ":emoji_1f45c:");
        emojisMap.put(0xe324, ":emoji_1f3ac:");
        emojisMap.put(0xe325, ":emoji_1f514:");
        emojisMap.put(0xe326, ":emoji_1f3b6:");
        emojisMap.put(0xe327, ":emoji_1f493:");
        emojisMap.put(0xe328, ":emoji_1f48c:");
        emojisMap.put(0xe329, ":emoji_1f498:");
        emojisMap.put(0xe32a, ":emoji_1f499:");
        emojisMap.put(0xe32b, ":emoji_1f49a:");
        emojisMap.put(0xe32c, ":emoji_1f49b:");
        emojisMap.put(0xe32d, ":emoji_1f49c:");
        emojisMap.put(0xe32e, ":emoji_2728:");
        emojisMap.put(0xe32f, ":emoji_2b50:");
        emojisMap.put(0xe330, ":emoji_1f4a8:");
        emojisMap.put(0xe331, ":emoji_1f4a6:");
        emojisMap.put(0xe332, ":emoji_2b55:");
        emojisMap.put(0xe333, ":emoji_2716:");
        emojisMap.put(0xe334, ":emoji_1f4a2:");
        emojisMap.put(0xe335, ":emoji_1f31f:");
        emojisMap.put(0xe336, ":emoji_2754:");
        emojisMap.put(0xe337, ":emoji_2755:");
        emojisMap.put(0xe338, ":emoji_1f375:");
        emojisMap.put(0xe339, ":emoji_1f35e:");
        emojisMap.put(0xe33a, ":emoji_1f366:");
        emojisMap.put(0xe33b, ":emoji_1f35f:");
        emojisMap.put(0xe33c, ":emoji_1f361:");
        emojisMap.put(0xe33d, ":emoji_1f358:");
        emojisMap.put(0xe33e, ":emoji_1f35a:");
        emojisMap.put(0xe33f, ":emoji_1f35d:");
        emojisMap.put(0xe340, ":emoji_1f35c:");
        emojisMap.put(0xe341, ":emoji_1f35b:");
        emojisMap.put(0xe342, ":emoji_1f359:");
        emojisMap.put(0xe343, ":emoji_1f362:");
        emojisMap.put(0xe344, ":emoji_1f363:");
        emojisMap.put(0xe345, ":emoji_1f34e:");
        emojisMap.put(0xe346, ":emoji_1f34a:");
        emojisMap.put(0xe347, ":emoji_1f353:");
        emojisMap.put(0xe348, ":emoji_1f349:");
        emojisMap.put(0xe349, ":emoji_1f345:");
        emojisMap.put(0xe34a, ":emoji_1f346:");
        emojisMap.put(0xe34b, ":emoji_1f382:");
        emojisMap.put(0xe34c, ":emoji_1f371:");
        emojisMap.put(0xe34d, ":emoji_1f372:");
        emojisMap.put(0xe401, ":emoji_1f625:");
        emojisMap.put(0xe402, ":emoji_1f60f:");
        emojisMap.put(0xe403, ":emoji_1f614:");
        emojisMap.put(0xe404, ":emoji_1f601:");
        emojisMap.put(0xe405, ":emoji_1f609:");
        emojisMap.put(0xe406, ":emoji_1f623:");
        emojisMap.put(0xe407, ":emoji_1f616:");
        emojisMap.put(0xe408, ":emoji_1f62a:");
        emojisMap.put(0xe409, ":emoji_1f445:");
        emojisMap.put(0xe40a, ":emoji_1f606:");
        emojisMap.put(0xe40b, ":emoji_1f628:");
        emojisMap.put(0xe40c, ":emoji_1f637:");
        emojisMap.put(0xe40d, ":emoji_1f633:");
        emojisMap.put(0xe40e, ":emoji_1f612:");
        emojisMap.put(0xe40f, ":emoji_1f630:");
        emojisMap.put(0xe410, ":emoji_1f632:");
        emojisMap.put(0xe411, ":emoji_1f62d:");
        emojisMap.put(0xe412, ":emoji_1f602:");
        emojisMap.put(0xe413, ":emoji_1f622:");
        emojisMap.put(0xe414, ":emoji_263a:");
        emojisMap.put(0xe415, ":emoji_1f605:");
        emojisMap.put(0xe416, ":emoji_1f621:");
        emojisMap.put(0xe417, ":emoji_1f61a:");
        emojisMap.put(0xe418, ":emoji_1f618:");
        emojisMap.put(0xe419, ":emoji_1f440:");
        emojisMap.put(0xe41a, ":emoji_1f443:");
        emojisMap.put(0xe41b, ":emoji_1f442:");
        emojisMap.put(0xe41c, ":emoji_1f444:");
        emojisMap.put(0xe41d, ":emoji_1f64f:");
        emojisMap.put(0xe41e, ":emoji_1f44b:");
        emojisMap.put(0xe41f, ":emoji_1f44f:");
        emojisMap.put(0xe420, ":emoji_1f44c:");
        emojisMap.put(0xe421, ":emoji_1f44e:");
        emojisMap.put(0xe422, ":emoji_1f450:");
        emojisMap.put(0xe423, ":emoji_1f645:");
        emojisMap.put(0xe424, ":emoji_1f646:");
        emojisMap.put(0xe425, ":emoji_1f491:");
        emojisMap.put(0xe426, ":emoji_1f647:");
        emojisMap.put(0xe427, ":emoji_1f64c:");
        emojisMap.put(0xe428, ":emoji_1f46b:");
        emojisMap.put(0xe429, ":emoji_1f46f:");
        emojisMap.put(0xe42a, ":emoji_1f3c0:");
        emojisMap.put(0xe42b, ":emoji_1f3c8:");
        emojisMap.put(0xe42c, ":emoji_1f3b1:");
        emojisMap.put(0xe42d, ":emoji_1f3ca:");
        emojisMap.put(0xe42e, ":emoji_1f699:");
        emojisMap.put(0xe42f, ":emoji_1f69a:");
        emojisMap.put(0xe430, ":emoji_1f692:");
        emojisMap.put(0xe431, ":emoji_1f691:");
        emojisMap.put(0xe432, ":emoji_1f693:");
        emojisMap.put(0xe433, ":emoji_1f3a2:");
        emojisMap.put(0xe434, ":emoji_1f687:");
        emojisMap.put(0xe435, ":emoji_1f684:");
        emojisMap.put(0xe436, ":emoji_1f38d:");
        emojisMap.put(0xe437, ":emoji_1f49d:");
        emojisMap.put(0xe438, ":emoji_1f38e:");
        emojisMap.put(0xe439, ":emoji_1f393:");
        emojisMap.put(0xe43a, ":emoji_1f392:");
        emojisMap.put(0xe43b, ":emoji_1f38f:");
        emojisMap.put(0xe43c, ":emoji_1f302:");
        emojisMap.put(0xe43d, ":emoji_1f492:");
        emojisMap.put(0xe43e, ":emoji_1f30a:");
        emojisMap.put(0xe43f, ":emoji_1f367:");
        emojisMap.put(0xe440, ":emoji_1f387:");
        emojisMap.put(0xe441, ":emoji_1f41a:");
        emojisMap.put(0xe442, ":emoji_1f390:");
        emojisMap.put(0xe443, ":emoji_1f300:");
        emojisMap.put(0xe444, ":emoji_1f33e:");
        emojisMap.put(0xe445, ":emoji_1f383:");
        emojisMap.put(0xe446, ":emoji_1f391:");
        emojisMap.put(0xe447, ":emoji_1f343:");
        emojisMap.put(0xe448, ":emoji_1f385:");
        emojisMap.put(0xe449, ":emoji_1f305:");
        emojisMap.put(0xe44a, ":emoji_1f307:");
        emojisMap.put(0xe44b, ":emoji_1f303:");
        emojisMap.put(0xe44b, ":emoji_1f30c:");
        emojisMap.put(0xe44c, ":emoji_1f308:");
        emojisMap.put(0xe501, ":emoji_1f3e9:");
        emojisMap.put(0xe502, ":emoji_1f3a8:");
        emojisMap.put(0xe503, ":emoji_1f3a9:");
        emojisMap.put(0xe504, ":emoji_1f3ec:");
        emojisMap.put(0xe505, ":emoji_1f3ef:");
        emojisMap.put(0xe506, ":emoji_1f3f0:");
        emojisMap.put(0xe507, ":emoji_1f3a6:");
        emojisMap.put(0xe508, ":emoji_1f3ed:");
        emojisMap.put(0xe509, ":emoji_1f5fc:");
        emojisMap.put(0xe50b, ":emoji_1f1ef_1f1f5:");
        emojisMap.put(0xe50c, ":emoji_1f1fa_1f1f8:");
        emojisMap.put(0xe50d, ":emoji_1f1eb_1f1f7:");
        emojisMap.put(0xe50e, ":emoji_1f1e9_1f1ea:");
        emojisMap.put(0xe50f, ":emoji_1f1ee_1f1f9:");
        emojisMap.put(0xe510, ":emoji_1f1ec_1f1e7:");
        emojisMap.put(0xe511, ":emoji_1f1ea_1f1f8:");
        emojisMap.put(0xe512, ":emoji_1f1f7_1f1fa:");
        emojisMap.put(0xe513, ":emoji_1f1e8_1f1f3:");
        emojisMap.put(0xe514, ":emoji_1f1f0_1f1f7:");
        emojisMap.put(0xe515, ":emoji_1f471:");
        emojisMap.put(0xe516, ":emoji_1f472:");
        emojisMap.put(0xe517, ":emoji_1f473:");
        emojisMap.put(0xe518, ":emoji_1f474:");
        emojisMap.put(0xe519, ":emoji_1f475:");
        emojisMap.put(0xe51a, ":emoji_1f476:");
        emojisMap.put(0xe51b, ":emoji_1f477:");
        emojisMap.put(0xe51c, ":emoji_1f478:");
        emojisMap.put(0xe51d, ":emoji_1f5fd:");
        emojisMap.put(0xe51e, ":emoji_1f482:");
        emojisMap.put(0xe51f, ":emoji_1f483:");
        emojisMap.put(0xe520, ":emoji_1f42c:");
        emojisMap.put(0xe521, ":emoji_1f426:");
        emojisMap.put(0xe522, ":emoji_1f420:");
        emojisMap.put(0xe523, ":emoji_1f423:");
        emojisMap.put(0xe524, ":emoji_1f439:");
        emojisMap.put(0xe525, ":emoji_1f41b:");
        emojisMap.put(0xe526, ":emoji_1f418:");
        emojisMap.put(0xe527, ":emoji_1f428:");
        emojisMap.put(0xe528, ":emoji_1f412:");
        emojisMap.put(0xe529, ":emoji_1f411:");
        emojisMap.put(0xe52a, ":emoji_1f43a:");
        emojisMap.put(0xe52b, ":emoji_1f42e:");
        emojisMap.put(0xe52c, ":emoji_1f430:");
        emojisMap.put(0xe52d, ":emoji_1f40d:");
        emojisMap.put(0xe52e, ":emoji_1f414:");
        emojisMap.put(0xe52f, ":emoji_1f417:");
        emojisMap.put(0xe530, ":emoji_1f42b:");
        emojisMap.put(0xe531, ":emoji_1f438:");
        emojisMap.put(0xe532, ":emoji_1f170:");
        emojisMap.put(0xe533, ":emoji_1f171:");
        emojisMap.put(0xe534, ":emoji_1f18e:");
        emojisMap.put(0xe535, ":emoji_1f17e:");
        emojisMap.put(0xe536, ":emoji_1f43e:");
        emojisMap.put(0xe537, ":emoji_2122:");

        //end softbank

        emojisMap.put(0x1f642, ":emoji_1f642:");
        emojisMap.put(0x1f917, ":emoji_1f917:");
        emojisMap.put(0x1f914, ":emoji_1f914:");
        emojisMap.put(0x1f644, ":emoji_1f644:");
        emojisMap.put(0x1f910, ":emoji_1f910:");
        emojisMap.put(0x1f913, ":emoji_1f913:");
        emojisMap.put(0x2639, ":emoji_2639:");
        emojisMap.put(0x1f641, ":emoji_1f641:");
        emojisMap.put(0x1f643, ":emoji_1f643:");
        emojisMap.put(0x1f912, ":emoji_1f912:");
        emojisMap.put(0x1f915, ":emoji_1f915:");
        emojisMap.put(0x1f911, ":emoji_1f911:");
        emojisMap.put(0x26d1, ":emoji_26d1:");
        emojisMap.put(0x1f575, ":emoji_1f575:");
        emojisMap.put(0x1f5e3, ":emoji_1f5e3:");
        emojisMap.put(0x1f574, ":emoji_1f574:");
        emojisMap.put(0x1f595, ":emoji_1f595:");
        emojisMap.put(0x1f918, ":emoji_1f918:");
        emojisMap.put(0x1f590, ":emoji_1f590:");
        emojisMap.put(0x270d, ":emoji_270d:");
        emojisMap.put(0x1f441, ":emoji_1f441:");
        emojisMap.put(0x2763, ":emoji_2763:");
        emojisMap.put(0x1f573, ":emoji_1f573:");
        emojisMap.put(0x1f5ef, ":emoji_1f5ef:");
        emojisMap.put(0x1f576, ":emoji_1f576:");
        emojisMap.put(0x1f6cd, ":emoji_1f6cd:");
        emojisMap.put(0x1f4ff, ":emoji_1f4ff:");
        emojisMap.put(0x2620, ":emoji_2620:");
        emojisMap.put(0x1f916, ":emoji_1f916:");
        emojisMap.put(0x1f981, ":emoji_1f981:");
        emojisMap.put(0x1f984, ":emoji_1f984:");
        emojisMap.put(0x1f43f, ":emoji_1f43f:");
        emojisMap.put(0x1f983, ":emoji_1f983:");
        emojisMap.put(0x1f54a, ":emoji_1f54a:");
        emojisMap.put(0x1f980, ":emoji_1f980:");
        emojisMap.put(0x1f577, ":emoji_1f577:");
        emojisMap.put(0x1f578, ":emoji_1f578:");
        emojisMap.put(0x1f982, ":emoji_1f982:");
        emojisMap.put(0x1f3f5, ":emoji_1f3f5:");
        emojisMap.put(0x2618, ":emoji_2618:");
        emojisMap.put(0x1f336, ":emoji_1f336:");
        emojisMap.put(0x1f9c0, ":emoji_1f9c0:");
        emojisMap.put(0x1f32d, ":emoji_1f32d:");
        emojisMap.put(0x1f32e, ":emoji_1f32e:");
        emojisMap.put(0x1f32f, ":emoji_1f32f:");
        emojisMap.put(0x1f37f, ":emoji_1f37f:");
        emojisMap.put(0x1f37e, ":emoji_1f37e:");
        emojisMap.put(0x1f37d, ":emoji_1f37d:");
        emojisMap.put(0x1f3fa, ":emoji_1f3fa:");
        emojisMap.put(0x1f5fa, ":emoji_1f5fa:");
        emojisMap.put(0x1f3d4, ":emoji_1f3d4:");
        emojisMap.put(0x26f0, ":emoji_26f0:");
        emojisMap.put(0x1f3d5, ":emoji_1f3d5:");
        emojisMap.put(0x1f3d6, ":emoji_1f3d6:");
        emojisMap.put(0x1f3dc, ":emoji_1f3dc:");
        emojisMap.put(0x1f3dd, ":emoji_1f3dd:");
        emojisMap.put(0x1f3de, ":emoji_1f3de:");
        emojisMap.put(0x1f3df, ":emoji_1f3df:");
        emojisMap.put(0x1f3db, ":emoji_1f3db:");
        emojisMap.put(0x1f3d7, ":emoji_1f3d7:");
        emojisMap.put(0x1f3d8, ":emoji_1f3d8:");
        emojisMap.put(0x1f3d9, ":emoji_1f3d9:");
        emojisMap.put(0x1f3da, ":emoji_1f3da:");
        emojisMap.put(0x1f6d0, ":emoji_1f6d0:");
        emojisMap.put(0x1f54b, ":emoji_1f54b:");
        emojisMap.put(0x1f54c, ":emoji_1f54c:");
        emojisMap.put(0x1f54d, ":emoji_1f54d:");
        emojisMap.put(0x1f5bc, ":emoji_1f5bc:");
        emojisMap.put(0x1f6e2, ":emoji_1f6e2:");
        emojisMap.put(0x1f6e3, ":emoji_1f6e3:");
        emojisMap.put(0x1f6e4, ":emoji_1f6e4:");
        emojisMap.put(0x1f6f3, ":emoji_1f6f3:");
        emojisMap.put(0x26f4, ":emoji_26f4:");
        emojisMap.put(0x1f6e5, ":emoji_1f6e5:");
        emojisMap.put(0x1f6e9, ":emoji_1f6e9:");
        emojisMap.put(0x1f6eb, ":emoji_1f6eb:");
        emojisMap.put(0x1f6ec, ":emoji_1f6ec:");
        emojisMap.put(0x1f6f0, ":emoji_1f6f0:");
        emojisMap.put(0x1f6ce, ":emoji_1f6ce:");
        emojisMap.put(0x1f6cc, ":emoji_1f6cc:");
        emojisMap.put(0x1f6cf, ":emoji_1f6cf:");
        emojisMap.put(0x1f6cb, ":emoji_1f6cb:");
        emojisMap.put(0x23f1, ":emoji_23f1:");
        emojisMap.put(0x23f2, ":emoji_23f2:");
        emojisMap.put(0x1f570, ":emoji_1f570:");
        emojisMap.put(0x1f321, ":emoji_1f321:");
        emojisMap.put(0x26c8, ":emoji_26c8:");
        emojisMap.put(0x1f324, ":emoji_1f324:");
        emojisMap.put(0x1f325, ":emoji_1f325:");
        emojisMap.put(0x1f326, ":emoji_1f326:");
        emojisMap.put(0x1f327, ":emoji_1f327:");
        emojisMap.put(0x1f328, ":emoji_1f328:");
        emojisMap.put(0x1f329, ":emoji_1f329:");
        emojisMap.put(0x1f32a, ":emoji_1f32a:");
        emojisMap.put(0x1f32b, ":emoji_1f32b:");
        emojisMap.put(0x1f32c, ":emoji_1f32c:");
        emojisMap.put(0x2602, ":emoji_2602:");
        emojisMap.put(0x26f1, ":emoji_26f1:");
        emojisMap.put(0x2603, ":emoji_2603:");
        emojisMap.put(0x2604, ":emoji_2604:");
        emojisMap.put(0x1f54e, ":emoji_1f54e:");
        emojisMap.put(0x1f396, ":emoji_1f396:");
        emojisMap.put(0x1f397, ":emoji_1f397:");
        emojisMap.put(0x1f39e, ":emoji_1f39e:");
        emojisMap.put(0x1f39f, ":emoji_1f39f:");
        emojisMap.put(0x1f3f7, ":emoji_1f3f7:");
        emojisMap.put(0x1f3cc, ":emoji_1f3cc:");
        emojisMap.put(0x26f8, ":emoji_26f8:");
        emojisMap.put(0x26f7, ":emoji_26f7:");
        emojisMap.put(0x26f9, ":emoji_26f9:");
        emojisMap.put(0x1f3cb, ":emoji_1f3cb:");
        emojisMap.put(0x1f3ce, ":emoji_1f3ce:");
        emojisMap.put(0x1f3cd, ":emoji_1f3cd:");
        emojisMap.put(0x1f3c5, ":emoji_1f3c5:");
        emojisMap.put(0x1f3cf, ":emoji_1f3cf:");
        emojisMap.put(0x1f3d0, ":emoji_1f3d0:");
        emojisMap.put(0x1f3d1, ":emoji_1f3d1:");
        emojisMap.put(0x1f3d2, ":emoji_1f3d2:");
        emojisMap.put(0x1f3d3, ":emoji_1f3d3:");
        emojisMap.put(0x1f3f8, ":emoji_1f3f8:");
        emojisMap.put(0x1f579, ":emoji_1f579:");
        emojisMap.put(0x23ed, ":emoji_23ed:");
        emojisMap.put(0x23ef, ":emoji_23ef:");
        emojisMap.put(0x23ee, ":emoji_23ee:");
        emojisMap.put(0x23f8, ":emoji_23f8:");
        emojisMap.put(0x23f9, ":emoji_23f9:");
        emojisMap.put(0x23fa, ":emoji_23fa:");
        emojisMap.put(0x1f399, ":emoji_1f399:");
        emojisMap.put(0x1f39a, ":emoji_1f39a:");
        emojisMap.put(0x1f39b, ":emoji_1f39b:");
        emojisMap.put(0x1f5a5, ":emoji_1f5a5:");
        emojisMap.put(0x1f5a8, ":emoji_1f5a8:");
        emojisMap.put(0x2328, ":emoji_2328:");
        emojisMap.put(0x1f5b1, ":emoji_1f5b1:");
        emojisMap.put(0x1f5b2, ":emoji_1f5b2:");
        emojisMap.put(0x1f4fd, ":emoji_1f4fd:");
        emojisMap.put(0x1f4f8, ":emoji_1f4f8:");
        emojisMap.put(0x1f56f, ":emoji_1f56f:");
        emojisMap.put(0x1f5de, ":emoji_1f5de:");
        emojisMap.put(0x1f5f3, ":emoji_1f5f3:");
        emojisMap.put(0x1f58b, ":emoji_1f58b:");
        emojisMap.put(0x1f58a, ":emoji_1f58a:");
        emojisMap.put(0x1f58c, ":emoji_1f58c:");
        emojisMap.put(0x1f58d, ":emoji_1f58d:");
        emojisMap.put(0x1f5c2, ":emoji_1f5c2:");
        emojisMap.put(0x1f5d2, ":emoji_1f5d2:");
        emojisMap.put(0x1f5d3, ":emoji_1f5d3:");
        emojisMap.put(0x1f587, ":emoji_1f587:");
        emojisMap.put(0x1f5c3, ":emoji_1f5c3:");
        emojisMap.put(0x1f5c4, ":emoji_1f5c4:");
        emojisMap.put(0x1f5d1, ":emoji_1f5d1:");
        emojisMap.put(0x1f5dd, ":emoji_1f5dd:");
        emojisMap.put(0x26cf, ":emoji_26cf:");
        emojisMap.put(0x2692, ":emoji_2692:");
        emojisMap.put(0x1f6e0, ":emoji_1f6e0:");
        emojisMap.put(0x2699, ":emoji_2699:");
        emojisMap.put(0x1f5dc, ":emoji_1f5dc:");
        emojisMap.put(0x2697, ":emoji_2697:");
        emojisMap.put(0x2696, ":emoji_2696:");
        emojisMap.put(0x26d3, ":emoji_26d3:");
        emojisMap.put(0x1f5e1, ":emoji_1f5e1:");
        emojisMap.put(0x2694, ":emoji_2694:");
        emojisMap.put(0x1f6e1, ":emoji_1f6e1:");
        emojisMap.put(0x1f3f9, ":emoji_1f3f9:");
        emojisMap.put(0x26b0, ":emoji_26b0:");
        emojisMap.put(0x26b1, ":emoji_26b1:");
        emojisMap.put(0x1f3f3, ":emoji_1f3f3:");
        emojisMap.put(0x1f3f4, ":emoji_1f3f4:");
        emojisMap.put(0x269c, ":emoji_269c:");
        emojisMap.put(0x269b, ":emoji_269b:");
        emojisMap.put(0x1f549, ":emoji_1f549:");
        emojisMap.put(0x2721, ":emoji_2721:");
        emojisMap.put(0x2638, ":emoji_2638:");
        emojisMap.put(0x262f, ":emoji_262f:");
        emojisMap.put(0x271d, ":emoji_271d:");
        emojisMap.put(0x2626, ":emoji_2626:");
        emojisMap.put(0x26e9, ":emoji_26e9:");
        emojisMap.put(0x262a, ":emoji_262a:");
        emojisMap.put(0x262e, ":emoji_262e:");
        emojisMap.put(0x2622, ":emoji_2622:");
        emojisMap.put(0x2623, ":emoji_2623:");
        emojisMap.put(0x1f5e8, ":emoji_1f5e8:");
    }

}
